@@ -44,7 +44,7 @@ class ModelRegistry:
             return
 
         if self.config.RUNTIME_ENV == "EDD":
-            res = EDDService(self.config).copy_file_to_s3(
+            res = EDDService(self.config).copy_model_to_s3(
                 model_path=f"{relative_path}/", model_name=lunar_model.name, model_version=lunar_model.version
             )
             if res["status"] != 200:
