@@ -7,7 +7,7 @@ from lunar.config import Config
 from lunar.lunar_client import LunarClient, LunarError
 from lunar.rec.experiments.models import Experiment, ExperimentPutIn, ExperimentPatchIn
 
-LUNAR_EXPERIMENTS_API_URL = "/v1/experiments"
+LUNAR_REC_EXPERIMENTS_API_URL = "/v1/experiments"
 
 loop = asyncio.get_event_loop()
 
@@ -28,7 +28,9 @@ class ExperimentClient(LunarClient):
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = LUNAR_EXPERIMENTS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_EXPERIMENTS_API_URL}"
+        self.api_url = (
+            LUNAR_REC_EXPERIMENTS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_REC_EXPERIMENTS_API_URL}"
+        )
 
     async def create_experiment_async(
         self, id: str, buckets: List[Dict[str, Any]], bucketing_seed: str = ""
